/*
	*
	* This file is a part of libpaper.
	* Library for handling various services related to Paper Shell.
	* Copyright 2020 CuboCore Group
	*

	*
	* This program is free software; you can redistribute it and/or modify
	* it under the terms of the GNU General Public License as published by
	* the Free Software Foundation; either version 3 of the License, or
	* ( at your option ) any later version.
	*

	*
	* This program is distributed in the hope that it will be useful,
	* but WITHOUT ANY WARRANTY; without even the implied warranty of
	* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	* GNU General Public License for more details.
	*

	*
	* You should have received a copy of the GNU General Public License
	* along with this program; if not, write to the Free Software
	* Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
	* MA 02110-1301, USA.
	*
*/

#pragma once

#include <QObject>

#include "paperglobals.h"

class QWindow;
class QTimer;
class QBasicTimer;

class layerSurface;
class dockHotspot;
class dockHotspotPrivate;

struct zwf_shell_manager_v2;
struct zwf_hotspot_v2;

class LIBPAPER_DLLSPEC dockHotspot : public QObject {
	Q_OBJECT;

public:
	enum Position {
		Top = 1 << 0,
		Bottom = 1 << 1,
		Left = 1 << 2,
		Right = 1 << 3
	};
	Q_ENUM(Position)

	dockHotspot(QWindow *window, zwf_shell_manager_v2 *wayfireShell, QObject *parent = nullptr);
	~dockHotspot();

	void createHotspot(dockHotspot::Position pos, uint height, uint duration);
	void destroy();

signals:
	void enteredHotspot();
	void leftHotspot();

protected:
	Q_DECLARE_PRIVATE(dockHotspot)
	dockHotspotPrivate *d_ptr;
};
