/*
	*
	* This file is a part of libpapershell-wl.
	* Library for handling various services related to Paper Shell.
	* Copyright 2020 CuboCore Group
	*

	*
	* This program is free software; you can redistribute it and/or modify
	* it under the terms of the GNU General Public License as published by
	* the Free Software Foundation; either version 3 of the License, or
	* (at your option) any later version.
	*

	*
	* This program is distributed in the hope that it will be useful,
	* but WITHOUT ANY WARRANTY; without even the implied warranty of
	* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	* GNU General Public License for more details.
	*

	*
	* You should have received a copy of the GNU General Public License
	* along with this program; if not, write to the Free Software
	* Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
	* MA 02110-1301, USA.
	*
*/

#pragma once

#include <QString>
#include "layershell.h" // TODO: must be removed from here

class QWindow;
class QWidget;
class QScreen;

struct wl_display;
struct wl_output;
struct wl_surface;
struct zwf_surface_v2;

class registrar;
class layerShell;
class layerSurface;
class dockAutoHide;

namespace PaperShell {

	/* Get the default wayland display */
	wl_display *getWlDisplay();

	/* Get the default wayland output for the given screen */
	wl_output *getWlOutput(QScreen *screen);

	/* Get the default wayland surface for the given window */
	wl_surface *getWlSurface(QWindow *window);

	/* Check if Wayland is running */
	bool isWaylandRunning();

	/* Create a background surface from window handle */
	layerSurface* setupShellSurface(QWindow *, layerShell *);

	/* Create a dock button surface from window handle */
	layerSurface *setupDockButtonSurface( QWindow *, layerShell * );

	/* Create a dockbar surface for a QWidget handle */
	layerSurface *setupDockBarSurface(QWidget *, layerShell *, layerSurface::SurfaceAnchors);
};
