/*
	*
	* This file is a part of libpaper.
	* Library for handling various services related to Paper Shell.
	* Copyright 2020 CuboCore Group
	*

	*
	* This program is free software; you can redistribute it and/or modify
	* it under the terms of the GNU General Public License as published by
	* the Free Software Foundation; either version 3 of the License, or
	* (at your option) any later version.
	*

	*
	* This program is distributed in the hope that it will be useful,
	* but WITHOUT ANY WARRANTY; without even the implied warranty of
	* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	* GNU General Public License for more details.
	*

	*
	* You should have received a copy of the GNU General Public License
	* along with this program; if not, write to the Free Software
	* Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
	* MA 02110-1301, USA.
	*
*/

#pragma once

#include <QObject>
#include <QMargins>
#include <QSize>

#include "paperglobals.h"

struct zwlr_layer_shell_v1;
struct zwlr_layer_surface_v1;

class QWindow;
class layerSurface;

class layerShellPrivate;
class layerSurfacePrivate;

class LIBPAPER_DLLSPEC layerShell : public QObject {
	Q_OBJECT

public:
	enum LayerType {
		Background = 0,
		Bottom = 1,
		Top = 2,
		Overlay = 3
	};

	layerShell(zwlr_layer_shell_v1 *lShell, QObject *parent = nullptr);
	~layerShell();

	zwlr_layer_surface_v1 *createlayerSurface(QWindow *window, LayerType layer, const QString &layer_namespace);

protected:
	Q_DECLARE_PRIVATE(layerShell)
	layerShellPrivate *d_ptr;
};

class LIBPAPER_DLLSPEC layerSurface : public QObject {
	Q_OBJECT

public:
	enum SurfaceAnchor {
		None = 0,
		Top = (1 << 0),
		Bottom = (1 << 1),
		Left = (1 << 2),
		Right = (1 << 3)
	};
	Q_DECLARE_FLAGS(SurfaceAnchors, SurfaceAnchor)

	layerSurface(QWindow *window, layerShell *lShell, QObject *parent = nullptr);
	~layerSurface();

	void initialize(layerShell::LayerType lt, const QString &layerNamespace);
	void apply();

	QWindow *getWindow() const;

	QSize getSurfaceSize() const;
	void setSurfaceSize(const QSize &surfaceSize);

	SurfaceAnchors getAnchors() const;
	void setAnchors(const SurfaceAnchors &anchors);

	int getExclusiveZone() const;
	void setExclusiveZone(int exclusiveZone);

	QMargins getMargins() const;
	void setMargins(const QMargins &margins);

	bool getKeyboardInteractivity() const;
	void setKeyboardInteractivity(bool keyboardInteractivity);

	QSize getSurfacePendingSize() const;

signals:
	void configured(QSize size);

protected:
	Q_DECLARE_PRIVATE(layerSurface)
	layerSurfacePrivate *d_ptr;
};

Q_DECLARE_OPERATORS_FOR_FLAGS(layerSurface::SurfaceAnchors)
