/*
	*
	* This file is a part of libpaper.
	* Library for handling various services related to Paper Shell.
	* Copyright 2020 CuboCore Group
	*

	*
	* This program is free software; you can redistribute it and/or modify
	* it under the terms of the GNU General Public License as published by
	* the Free Software Foundation; either version 3 of the License, or
	* (at your option) any later version.
	*

	*
	* This program is distributed in the hope that it will be useful,
	* but WITHOUT ANY WARRANTY; without even the implied warranty of
	* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	* GNU General Public License for more details.
	*

	*
	* You should have received a copy of the GNU General Public License
	* along with this program; if not, write to the Free Software
	* Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
	* MA 02110-1301, USA.
	*
*/

#pragma once

#include <QObject>

#include "paperglobals.h"

struct wl_seat;
struct wl_display;
struct wl_compositor;
struct zwlr_layer_shell_v1;
struct zwf_shell_manager_v2;
struct zwlr_foreign_toplevel_manager_v1;

class registrarPrivate;
class layerShell;
class toplevelManager;

class LIBPAPER_DLLSPEC registrar : public QObject {
	Q_OBJECT

public:
	enum ErrorType {
		EmptyWayfireShell,
		EmptyCompositor,
		EmptySeat,
		EmptylayerShell,
		EmptyToplevelManager
	};
	Q_ENUM(ErrorType)

	registrar();
	registrar(wl_display *wlDisplay);
	~registrar();

	void initialize();

	wl_display *wlDisplay() const;
	wl_seat *wlSeat() const;
	wl_compositor *wlCompositor() const;
	zwlr_layer_shell_v1 *wlrlayerShell() const;
	zwlr_foreign_toplevel_manager_v1 *wlrToplevelManager() const;
	zwf_shell_manager_v2 *wayfireShell() const;

	layerShell *lShell() const;
	toplevelManager *tlManager() const;

signals:
	void errorOccured(ErrorType et);

protected:
	Q_DECLARE_PRIVATE(registrar)
	registrarPrivate *d_ptr;
};
