/*
	*
	* This file is a part of libpapershell-wl.
	* Library for handling various services related to Paper Shell.
	* Copyright 2020 CuboCore Group
	*

	*
	* This program is free software; you can redistribute it and/or modify
	* it under the terms of the GNU General Public License as published by
	* the Free Software Foundation; either version 3 of the License, or
	* (at your option) any later version.
	*

	*
	* This program is distributed in the hope that it will be useful,
	* but WITHOUT ANY WARRANTY; without even the implied warranty of
	* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	* GNU General Public License for more details.
	*

	*
	* You should have received a copy of the GNU General Public License
	* along with this program; if not, write to the Free Software
	* Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
	* MA 02110-1301, USA.
	*
*/

#pragma once

#include "qwayland-wlr-foreign-toplevel-management-unstable-v1.h"
#include "toplevelmanager.h"

class toplevelManagerPrivate : public QtWayland::zwlr_foreign_toplevel_manager_v1 {

public:
	toplevelManagerPrivate(struct ::zwlr_foreign_toplevel_manager_v1 *tlManager, struct wl_seat *seat, toplevelManager *ptr);
	~toplevelManagerPrivate();

protected:
	void zwlr_foreign_toplevel_manager_v1_toplevel(struct ::zwlr_foreign_toplevel_handle_v1 *handle) override;
	void zwlr_foreign_toplevel_manager_v1_finished() override;

	Q_DISABLE_COPY(toplevelManagerPrivate)
	Q_DECLARE_PUBLIC(toplevelManager)
	toplevelManager *q_ptr;

private:
	wl_seat *m_seat;
	bool m_showingDesktop;
	toplevelHandleList m_tlHandleList;
	QMap<toplevelHandle *, uint32_t> m_tls;

	void closeHandle(toplevelHandle *handle);
	void showDesktop();
	void minimizeAll();
	void storeAndMinimizeHandle(toplevelHandle *handle);
};

class toplevelHandlePrivate : public QtWayland::zwlr_foreign_toplevel_handle_v1 {

public:
	toplevelHandlePrivate(struct ::zwlr_foreign_toplevel_handle_v1 *tlHandle, toplevelHandle *ptr);
	~toplevelHandlePrivate();

protected:
	void zwlr_foreign_toplevel_handle_v1_title(const QString &title) override;
	void zwlr_foreign_toplevel_handle_v1_app_id(const QString &app_id) override;
	void zwlr_foreign_toplevel_handle_v1_output_enter(struct ::wl_output *output) override;
	void zwlr_foreign_toplevel_handle_v1_output_leave(struct ::wl_output *output) override;
	void zwlr_foreign_toplevel_handle_v1_state(wl_array *state) override;
	void zwlr_foreign_toplevel_handle_v1_done() override;
	void zwlr_foreign_toplevel_handle_v1_closed() override;

	Q_DISABLE_COPY(toplevelHandlePrivate)
	Q_DECLARE_PUBLIC(toplevelHandle)
	toplevelHandle *q_ptr;

private:
	QString m_appID;
	QString m_appTitle;
	toplevelHandle::ToplevelStates m_appStates;
};
